@@ -3,8 +3,6 @@
 import numpy as np
 import tables as tb
 
-# This class is accessible only for the examples
-
 
 class Small(tb.IsDescription):
     var1 = tb.StringCol(itemsize=4, pos=2)
@@ -271,18 +269,11 @@ if __name__ == "__main__":
     import sys
     import getopt
 
-    try:
-        import psyco
-        psyco_imported = 1
-    except:
-        psyco_imported = 0
-
     from time import perf_counter as clock
     from time import process_time as cpuclock
 
-    usage = """usage: %s [-v] [-p] [-P] [-R range] [-r] [-w] [-s recsize] [-f field] [-c level] [-l complib] [-i iterations] [-S] [-F] file
+    usage = """usage: %s [-v] [-P] [-R range] [-r] [-w] [-s recsize] [-f field] [-c level] [-l complib] [-n nrows] [-S] [-B] [-F] file
             -v verbose
-            -p use "psyco" if available
             -P do profile
             -R select a range in a field in the form "start,stop,step"
             -r only read test
@@ -290,13 +281,14 @@ if __name__ == "__main__":
             -s use [big] record, [medium] or [small]
             -f only read stated field name in tables ("all" means all fields)
             -c sets a compression level (do not set it or 0 for no compression)
-            -S activate shuffling filter
+            -S activate shuffle filter
+            -B activate bitshuffle filter
             -F activate fletcher32 filter
             -l sets the compression library to be used ("zlib", "lzo", "blosc", "bzip2")
-            -i sets the number of rows in each table\n""" % sys.argv[0]
+            -n sets the number of rows in each table\n""" % sys.argv[0]
 
     try:
-        opts, pargs = getopt.getopt(sys.argv[1:], 'vpPSFR:rwf:s:c:l:i:')
+        opts, pargs = getopt.getopt(sys.argv[1:], 'vPSBFR:rwf:s:c:l:n:')
     except:
         sys.stderr.write(usage)
         sys.exit(0)
@@ -314,23 +306,22 @@ if __name__ == "__main__":
     fieldName = None
     testread = 1
     testwrite = 1
-    usepsyco = 0
-    complevel = 0
+    complevel = 9
     shuffle = 0
     fletcher32 = 0
-    complib = "zlib"
-    iterations = 100
+    complib = "blosc2:blosclz"
+    nrows = 1_000_000
 
     # Get the options
     for option in opts:
         if option[0] == '-v':
             verbose = 1
-        if option[0] == '-p':
-            usepsyco = 1
         if option[0] == '-P':
             profile = 1
         if option[0] == '-S':
             shuffle = 1
+        if option[0] == '-B':
+            shuffle = 2  # bitshuffle
         if option[0] == '-F':
             fletcher32 = 1
         elif option[0] == '-R':
@@ -350,36 +341,36 @@ if __name__ == "__main__":
             complevel = int(option[1])
         elif option[0] == '-l':
             complib = option[1]
-        elif option[0] == '-i':
-            iterations = int(option[1])
+        elif option[0] == '-n':
+            nrows = int(option[1])
 
     # Build the Filters instance
     filters = tb.Filters(complevel=complevel, complib=complib,
-                         shuffle=shuffle, fletcher32=fletcher32)
+                         shuffle=(True if shuffle == 1 else False),
+                         bitshuffle=(True if shuffle == 2 else False),
+                         fletcher32=fletcher32)
 
     # Catch the hdf5 file passed as the last argument
     file = pargs[0]
 
     if verbose:
         print("numpy version:", np.__version__)
-        if psyco_imported and usepsyco:
-            print("Using psyco version:", psyco.version_info)
 
     if testwrite:
         print("Compression level:", complevel)
         if complevel > 0:
             print("Compression library:", complib)
-            if shuffle:
-                print("Suffling...")
+            if shuffle == 1:
+                print("Shuffling...")
+            elif shuffle == 2:
+                print("Bitshuffling...")
         t1 = clock()
         cpu1 = cpuclock()
-        if psyco_imported and usepsyco:
-            psyco.bind(createFile)
         if profile:
             import profile as prof
             import pstats
             prof.run(
-                '(rowsw, rowsz) = createFile(file, iterations, filters, '
+                '(rowsw, rowsz) = createFile(file, nrows, filters, '
                 'recsize)',
                 'table-bench.prof')
             stats = pstats.Stats('table-bench.prof')
@@ -387,7 +378,7 @@ if __name__ == "__main__":
             stats.sort_stats('time', 'calls')
             stats.print_stats(20)
         else:
-            (rowsw, rowsz) = createFile(file, iterations, filters, recsize)
+            (rowsw, rowsz) = createFile(file, nrows, filters, recsize)
         t2 = clock()
         cpu2 = cpuclock()
         tapprows = t2 - t1
@@ -396,16 +387,12 @@ if __name__ == "__main__":
         print(
             f"Time writing rows: {tapprows:.3f} s (real) "
             f"{cpuapprows:.3f} s (cpu)  {cpuapprows / tapprows:.0%}")
-        print(f"Write rows/sec:  {rowsw / tapprows}")
-        print(f"Write KB/s : {rowsw * rowsz / (tapprows * 1024):.0f}")
+        print(f"Write Mrows/sec:  {rowsw / (tapprows * 1e6):.3f}")
+        print(f"Write MB/s : {rowsw * rowsz / (tapprows * 1024 * 1024):.3f}")
 
     if testread:
         t1 = clock()
         cpu1 = cpuclock()
-        if psyco_imported and usepsyco:
-            psyco.bind(readFile)
-            # psyco.bind(readField)
-            pass
         if rng or fieldName:
             (rowsr, rowsz) = readField(file, fieldName, rng, verbose)
             pass
@@ -416,9 +403,9 @@ if __name__ == "__main__":
         cpu2 = cpuclock()
         treadrows = t2 - t1
         cpureadrows = cpu2 - cpu1
-        print(f"Rows read: {rowsw}  Row size: {rowsz}")
+        print(f"Rows read: {rowsr}  Row size: {rowsz}")
         print(
             f"Time reading rows: {treadrows:.3f} s (real) "
             f"{cpureadrows:.3f} s (cpu)  {cpureadrows / treadrows:.0%}")
-        print(f"Read rows/sec:  {rowsr / treadrows}")
-        print(f"Read KB/s : {rowsr * rowsz / (treadrows * 1024):.0f}")
+        print(f"Read Mrows/sec:  {rowsr / (treadrows * 1e6):.3f}")
+        print(f"Read MB/s : {rowsr * rowsz / (treadrows * 1024 * 1024):.3f}")
