@@ -3,9 +3,9 @@ from time import perf_counter as clock
 import numpy as np
 import tables as tb
 
-N = 144_000
-#N = 144
+N = 10_000_000
 
+filters = tb.Filters(9, "blosc2", shuffle=True)
 
 def timed(func, *args, **kwargs):
     start = clock()
@@ -16,12 +16,12 @@ def timed(func, *args, **kwargs):
 
 def create_table(output_path):
     print("creating array...", end=' ')
-    dt = np.dtype([('field%d' % i, int) for i in range(320)])
+    dt = np.dtype([('field%d' % i, int) for i in range(32)])
     a = np.zeros(N, dtype=dt)
     print("done.")
 
     output_file = tb.open_file(output_path, mode="w")
-    table = output_file.create_table("/", "test", dt)  # , filters=blosc4)
+    table = output_file.create_table("/", "test", dt, filters=filters)
     print("appending data...", end=' ')
     table.append(a)
     print("flushing...", end=' ')
@@ -36,7 +36,7 @@ def copy1(input_path, output_path):
     output_file = tb.open_file(output_path, mode="w")
 
     # copy nodes as a batch
-    input_file.copy_node("/", output_file.root, recursive=True)
+    input_file.copy_node("/", output_file.root, recursive=True, filters=filters)
     output_file.close()
     input_file.close()
 
@@ -44,57 +44,57 @@ def copy1(input_path, output_path):
 def copy2(input_path, output_path):
     print(f"copying data from {input_path} to {output_path}...")
     input_file = tb.open_file(input_path, mode="r")
-    input_file.copy_file(output_path, overwrite=True)
+    input_file.copy_file(output_path, overwrite=True, filters=filters)
     input_file.close()
 
 
 def copy3(input_path, output_path):
     print(f"copying data from {input_path} to {output_path}...")
     input_file = tb.open_file(input_path, mode="r")
-    output_file = tb.open_file(output_path, mode="w")
+    output_file = tb.open_file(output_path, mode="w", filters=filters)
     table = input_file.root.test
     table.copy(output_file.root)
     output_file.close()
     input_file.close()
 
 
-def copy4(input_path, output_path, complib='zlib', complevel=0):
+def copy4(input_path, output_path):
     print(f"copying data from {input_path} to {output_path}...")
     input_file = tb.open_file(input_path, mode="r")
-    output_file = tb.open_file(output_path, mode="w")
+    output_file = tb.open_file(output_path, mode="w", filters=filters)
 
     input_table = input_file.root.test
     print("reading data...", end=' ')
+    start = clock()
     data = input_file.root.test.read()
+    print(f"{clock() - start:.3f}s elapsed.")
     print("done.")
 
-    filter = tb.Filters(complevel=complevel, complib=complib)
-    output_table = output_file.create_table("/", "test", input_table.dtype,
-                                            filters=filter)
+    output_table = output_file.create_table("/", "test", input_table.dtype)
     print("appending data...", end=' ')
+    start = clock()
     output_table.append(data)
     print("flushing...", end=' ')
     output_table.flush()
+    print(f"{clock() - start:.3f}s elapsed.")
     print("done.")
 
     input_file.close()
     output_file.close()
 
 
-def copy5(input_path, output_path, complib='zlib', complevel=0):
+def copy5(input_path, output_path):
     print(f"copying data from {input_path} to {output_path}...")
     input_file = tb.open_file(input_path, mode="r")
-    output_file = tb.open_file(output_path, mode="w")
+    output_file = tb.open_file(output_path, mode="w", filters=filters)
 
     input_table = input_file.root.test
+    output_table = output_file.create_table("/", "test", input_table.dtype)
 
-    filter = tb.Filters(complevel=complevel, complib=complib)
-    output_table = output_file.create_table("/", "test", input_table.dtype,
-                                            filters=filter)
-    chunksize = 10_000
+    chunksize = 100_000
     rowsleft = len(input_table)
     start = 0
-    for chunk in range((len(input_table) / chunksize) + 1):
+    for chunk in range(int(len(input_table) / chunksize) + 1):
         stop = start + min(chunksize, rowsleft)
         data = input_table.read(start, stop)
         output_table.append(data)
@@ -108,8 +108,8 @@ def copy5(input_path, output_path, complib='zlib', complevel=0):
 
 if __name__ == '__main__':
     timed(create_table, 'tmp.h5')
-#    timed(copy1, 'tmp.h5', 'test1.h5')
+    timed(copy1, 'tmp.h5', 'test1.h5')
     timed(copy2, 'tmp.h5', 'test2.h5')
-#    timed(copy3, 'tmp.h5', 'test3.h5')
+    timed(copy3, 'tmp.h5', 'test3.h5')
     timed(copy4, 'tmp.h5', 'test4.h5')
     timed(copy5, 'tmp.h5', 'test5.h5')
