@@ -5,6 +5,7 @@
 #include "H5Zlzo.h"                    /* Import FILTER_LZO */
 #include "H5Zbzip2.h"                  /* Import FILTER_BZIP2 */
 #include "blosc_filter.h"              /* Import FILTER_BLOSC */
+#include "blosc2_filter.h"             /* Import FILTER_BLOSC2 */
 
 #include <string.h>
 #include <stdlib.h>
@@ -45,7 +46,7 @@ hid_t H5ARRAYmake(  hid_t loc_id,
                     char  *complib,
                     int   shuffle,
                     int   fletcher32,
-		    hbool_t track_times,
+                    hbool_t track_times,
                     const void *data)
 {
 
@@ -131,6 +132,23 @@ hid_t H5ARRAYmake(  hid_t loc_id,
        if ( H5Pset_deflate( plist_id, compress) < 0 )
          return -1;
      }
+     /* The Blosc2 compressor does accept parameters (see blosc2_filter.c) */
+     else if (strcmp(complib, "blosc2") == 0) {
+       cd_values[4] = compress;
+       cd_values[5] = shuffle;
+       if ( H5Pset_filter( plist_id, FILTER_BLOSC2, H5Z_FLAG_OPTIONAL, 6, cd_values) < 0 )
+         return -1;
+      }
+      /* The Blosc2 compressor can use other compressors (see blosc2_filter.c) */
+     else if (strncmp(complib, "blosc2:", 7) == 0) {
+       cd_values[4] = compress;
+       cd_values[5] = shuffle;
+       blosc_compname = complib + 7;
+       blosc_compcode = blosc2_compname_to_compcode(blosc_compname);
+       cd_values[6] = blosc_compcode;
+       if ( H5Pset_filter( plist_id, FILTER_BLOSC2, H5Z_FLAG_OPTIONAL, 7, cd_values) < 0 )
+         return -1;
+     }
      /* The Blosc compressor does accept parameters */
      else if (strcmp(complib, "blosc") == 0) {
        cd_values[4] = compress;
@@ -256,7 +274,7 @@ herr_t H5ARRAYappend_records( hid_t dataset_id,
    start[i] = 0;
  }
  dims[extdim] += dims_new[extdim];
- start[extdim] = (hsize_t )dims_orig[extdim];
+ start[extdim] = (hsize_t)dims_orig[extdim];
 
  /* Extend the dataset */
  if ( H5Dset_extent( dataset_id, dims ) < 0 )
